########################################################################################################################
# Governing R code to run model checking for Mixed Number Subtraction BN example

# data file should be in the Data folder
# coda files for 3 chains should be in the coda folder
########################################################################################################################

rm(list=ls())


########################################################################################################################
# Define the 
#   main analysis folder
#   R folder
#   Data folder
#   coda folder
########################################################################################################################
main.folder <- "C:\\BPM\\BN for Mixed Number Subtraction\\"
R.folder <- paste(main.folder, "R\\", sep="")
data.folder <- paste(main.folder, "Data\\", sep="")
coda.folder <- paste(main.folder, "coda files\\", sep="")




########################################################################################################################
# Read in the observed data
########################################################################################################################
file.name <- "Mixed Number Subtraction.dat"
x <- as.matrix(read.table(paste(data.folder, file.name, sep=""), header=TRUE))



############################################################################################################################
# Extract features
# n is the number of examinees
# J is the number of observables
############################################################################################################################
n <- nrow(x)
J <- ncol(x)




########################################################################################################################
# PPMC Analyses
########################################################################################################################
  
  ###########################################################################
  # Read in the draws from the coda folder
  ###########################################################################
  bugs.sim <-  c("coda1.txt", "coda2.txt", "coda3.txt")
  setwd(coda.folder)
  file.name <- "Read in Draws.R"
  source(paste(R.folder, file.name, sep=""))



  ###########################################################################
  # Create PPMC folder if it isn't there
  ###########################################################################
  PPMC.folder <- paste(main.folder, "PPMC Analyses\\", sep="")
  dir.create(PPMC.folder)
  
  ###########################################################################
  #  Declare burnin and thin if needed
  ###########################################################################
  n.burnin=1000
  n.thin.for.PPMC=3
  
  #############################################################################################################################
  # Select the iterations to summarize
  #############################################################################################################################
  draws.to.analyze <- window(draws.from.bugs,
    start=n.burnin+1, thin=n.thin.for.PPMC)
  
  
  #########################################################################################################################
  # Convert the draws to a matrix
  #########################################################################################################################
  draws.to.analyze.as.matrix <- as.matrix(draws.to.analyze)
  dim(draws.to.analyze.as.matrix)
  
  
  
  #########################################################################################################################
  # Remove the original draws from BUGS, so as to avoid any errors
  #########################################################################################################################
  rm(draws.from.bugs, draws.from.bugs.as.matrix)


  
  ########################################################################################################################
  # Run 'PPMC Analyses.R' 
  ########################################################################################################################
  n.iters.PPMC <- dim(draws.to.analyze.as.matrix)[1]
  setwd(PPMC.folder)
  output.folder <- PPMC.folder
  file.name <- "PPMC Analyses.R"
  source(paste(R.folder, file.name, sep=""))

